netapp_ontap.models.port_statistics_device API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.port_statistics_device`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class PortStatisticsDeviceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the PortStatisticsDevice object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `link_down_count_raw GET`

    The number of link state changes from up to down seen on the device.

    Example: 3

  `receive_raw GET`

    The receive_raw field of the port_statistics_device.

  `timestamp GET`

    The timestamp when the device specific counters were collected.

    Example: 2017-01-25T11:20:13.000+0000

  `transmit_raw GET`

    The transmit_raw field of the port_statistics_device.